#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <QDialog>

#include <QtMaemo5>
#include <QtCore>
#include <QtGui>

namespace Ui {
    class SettingsDialog;
}

class SettingsDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SettingsDialog(QWidget *parent = 0);
    ~SettingsDialog();

signals:
    void saveButtonClicked();

private slots:
    void on_icon2Button_clicked();
    void on_icon1Button_clicked();
    void on_saveButton_clicked();

private:
    Ui::SettingsDialog *ui;

    QMaemo5InformationBox infoBox;
    QLabel labelBox;

    bool hideWhenClosing;
    bool showNotifications;
    bool showNotificationsOnlyWhenScreenIsOn;
    bool showNotificationsOnlyWhenWindowIsActiveOrViewNotPlayingNow;

    void setIcons();
    void readSettings();
    void saveSettings();
};

#endif // SETTINGSDIALOG_H
